==> bootstrap-react-2.2.0-beta.1.tgz: package/lib/page-proxy.js <==
import "core-js/modules/es6.promise";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.string.iterator";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import "core-js/modules/es6.regexp.match";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import React, { Component } from 'react';
var STR_DEFAULT = 'default';

var PageProxy =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(PageProxy, _Component);

  function PageProxy() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      hasError: false
    };
    return _this;
  }

  var _proto = PageProxy.prototype;

  _proto.getPagePath = function getPagePath() {
    var _this$props = this.props,
        url = _this$props.match.url,
        _this$props$homePage = _this$props.homePage,
        homePage = _this$props$homePage === void 0 ? 'home' : _this$props$homePage;
    return url.substr(1) || homePage;
  };

  _proto.componentDidMount = function componentDidMount() {
    this.loadAsyncPages(this.getPagePath());
  };

  PageProxy.getDerivedStateFromError = function getDerivedStateFromError(error) {
    return {
      hasError: true,
      error: error
    };
  };

  _proto.renderPageElement = function renderPageElement(Loading) {
    var state = this.state;
    var pagePath = this.getPagePath();
    var Page = state[pagePath];

    if (Page) {
      var useLayout = Page.useLayout;
      this.useLayout = typeof useLayout === 'boolean' ? useLayout : true; //缓存当前useLayout的状态，进入下一个页面的时候避免发生layout的切换导致的闪动

      return [React.createElement(Page, this.props), this.useLayout];
    } //读取之前的layout状态，如果不存在就用true


    this.loadAsyncPages(pagePath);
    var ul = this.useLayout === 'boolean' ? this.useLayout : true;
    return [Loading ? React.createElement(Loading, null) : null, ul];
  };

  _proto.render = function render() {
    var _this$props2 = this.props,
        ErrorComp = _this$props2.ErrorComp,
        Layout = _this$props2.Layout,
        LoadingComp = _this$props2.LoadingComp,
        props = _objectWithoutPropertiesLoose(_this$props2, ["ErrorComp", "Layout", "LoadingComp"]);

    if (this.state.hasError) {
      if (ErrorComp) {
        return React.createElement(ErrorComp, _extends({
          error: this.state.error
        }, props));
      } else {
        typeof console.err === 'function' && console.err(this.state.err);
      }
    }

    var _this$renderPageEleme = this.renderPageElement(LoadingComp),
        pageElement = _this$renderPageEleme[0],
        useLayout = _this$renderPageEleme[1];

    if (!useLayout || !Layout) return pageElement;
    return React.createElement(Layout, this.props, pageElement);
  };

  _proto.loadAsyncPages = function loadAsyncPages(path) {
    var _this2 = this;

    var loadPage = import(
    /* webpackMode: "lazy", webpackChunkName: "[request]" */
    "_/src/pages/" + path + "/page-view");
    Promise.all([loadPage]).then(function (_ref) {
      var loadedModule = _ref[0];
      var needUpdate = false;
      var updateData = {};
      var PageComponent = loadedModule[STR_DEFAULT];

      if (PageComponent) {
        needUpdate = true;
        updateData[path] = PageComponent;
      }

      if (needUpdate) {
        _this2.setState(updateData);
      }
    }).catch(function (err) {
      _this2.setState({
        hasError: true,
        error: err
      });
    });
  };

  return PageProxy;
}(Component);

export { PageProxy as default };

==> bootstrap-react-2.3.0-beta.1.tgz: package/lib/page-proxy.js <==
import "core-js/modules/es6.promise";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.string.iterator";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import "core-js/modules/es6.regexp.match";
import React, { Component } from 'react';
var STR_DEFAULT = 'default';
var currentPagePath = '';

function getPagePath(props) {
  var getPagePath = props.getPagePath,
      url = props.match.url,
      _props$homePage = props.homePage,
      homePage = _props$homePage === void 0 ? 'home' : _props$homePage;
  if (typeof getPagePath === 'function') return getPagePath(props) || homePage;
  return url.substr(1) || homePage;
}

var PageProxy =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(PageProxy, _Component);

  function PageProxy() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      hasError: false
    };
    return _this;
  }

  PageProxy.getDerivedStateFromError = function getDerivedStateFromError(error) {
    return {
      hasError: true,
      error: error
    };
  } //当上个路由出错时，切换页面清楚错误
  ;

  PageProxy.getDerivedStateFromProps = function getDerivedStateFromProps(props, state) {
    var newPagePath = getPagePath(props);

    if (newPagePath !== currentPagePath && state.hasError) {
      return {
        hasError: false,
        error: null
      };
    }

    return null;
  };

  var _proto = PageProxy.prototype;

  _proto.renderPageElement = function renderPageElement(Loading) {
    var state = this.state;
    var pagePath = currentPagePath = getPagePath(this.props);
    var Page = state[pagePath];

    if (Page) {
      var useLayout = Page.useLayout;
      this.useLayout = typeof useLayout === 'boolean' ? useLayout : true; //缓存当前useLayout的状态，进入下一个页面的时候避免发生layout的切换导致的闪动

      return [React.createElement(Page, this.props), this.useLayout];
    } //读取之前的layout状态，如果不存在就用true


    this.loadAsyncPages(pagePath);
    var ul = this.useLayout === 'boolean' ? this.useLayout : true;
    return [Loading ? React.createElement(Loading, null) : React.createElement("div", {
      className: "page_proxy_waiting_element"
    }), ul];
  };

  _proto.render = function render() {
    var _this$props = this.props,
        ErrorComp = _this$props.ErrorComp,
        Layout = _this$props.Layout,
        LoadingComp = _this$props.LoadingComp,
        props = _objectWithoutPropertiesLoose(_this$props, ["ErrorComp", "Layout", "LoadingComp"]);

    if (this.state.hasError) {
      if (ErrorComp) {
        return React.createElement(ErrorComp, _extends({
          error: this.state.error
        }, props));
      } else {
        typeof console.error === 'function' && console.error(this.state.error.message);
        return React.createElement("div", {
          className: "page_proxy_error_element"
        });
      }
    }

    var _this$renderPageEleme = this.renderPageElement(LoadingComp),
        pageElement = _this$renderPageEleme[0],
        useLayout = _this$renderPageEleme[1];

    if (!useLayout || !Layout) return pageElement;
    return React.createElement(Layout, this.props, pageElement);
  };

  _proto.loadAsyncPages = function loadAsyncPages(path) {
    var _this2 = this;

    var loadPage = import(
    /* webpackMode: "lazy", webpackChunkName: "[request]" */
    "_/src/pages/" + path + "/page-view");
    Promise.all([loadPage]).then(function (_ref) {
      var loadedModule = _ref[0];
      var needUpdate = false;
      var updateData = {};
      var PageComponent = loadedModule[STR_DEFAULT];

      if (PageComponent) {
        needUpdate = true;
        updateData[path] = PageComponent;
      }

      if (needUpdate) {
        _this2.setState(updateData);
      }
    }).catch(function (err) {
      _this2.setState({
        hasError: true,
        error: err
      });
    });
  };

  return PageProxy;
}(Component);

export { PageProxy as default };
